from datetime import datetime, timedelta

from common.utils import logging
from common.utils.baseline.core import BaselineService
from common.utils.checkpoint.core import CheckpointService
from common.utils.event.core import EventService
from common.utils.flow.core import FlowService
from common.utils.lookup.core import LookupService
from common.utils.userconfig.core import UserConfigService
from llmnrnbtns.detector.core import LlmnrNbtns


def main():
    """ Main function for detector

    Runs the detector for the current day, if it's 2am, run a second time
    for the previous day
    """

    now = datetime.now()
    llmnr_nbtns = init_llmnr_nbtns_with_time(now)

    logger.info("starting llmnrnbtns")
    llmnr_nbtns.run()
    logger.info("ending llmnrnbtns")

    if now.hour == 2:
        logger.info("running during hour 2, triggering run for yesterday")
        end_of_yesterday = datetime.combine(
            now.date() - timedelta(days=1), datetime.max.time())
        llmnr_nbtns = init_llmnr_nbtns_with_time(end_of_yesterday)

        logger.info("starting llmnrnbtns for yesterday")
        llmnr_nbtns.run()
        logger.info("ending llmnrnbtns for yesterday")


def init_llmnr_nbtns_with_time(time: datetime) -> LlmnrNbtns:
    flow_service = FlowService()
    return LlmnrNbtns(
        BaselineService(),
        CheckpointService(),
        UserConfigService(),
        EventService(),
        flow_service,
        LookupService(flow_service),
        time
    )


if __name__ == "__main__":
    logger = logging.get_common_logger(__file__)
    logger.info("initializing llmnrnbtns detector")
    main()
